@@ -8,8 +8,6 @@
 # "pub/qos1/receive", payload of "message", QoS=1 and mid=123. The client
 # should handle this as per the spec by sending a PUBACK message.
 # The client should then exit with return code==0.
-import pytest
-
 import tests.paho_test as paho_test
 
 connect_packet = paho_test.gen_connect("publish-qos1-test", keepalive=60)
@@ -23,8 +21,6 @@ publish_packet = paho_test.gen_publish(
 puback_packet = paho_test.gen_puback(mid)
 
 
-# msg.retain changed when typing was added
-@pytest.mark.xfail
 def test_03_publish_b2c_qos1(server_socket, start_client):
     start_client("03-publish-b2c-qos1.py")
 
